% ModelWaveform Function: Version 3
% Author: Jacob Neumann
% Created: 29 January 2017
% [Intensity,Length] = ModelWaveform(Target,Mask) computes the predicted waveform on a PMT or photodiode
% when the target (Target) is passed under the mask (Mask).  
% Function returns the intensity waveform vector and the length of the vector
% # Rows of Target must = # Rows of Mask

function [Intensity,Length] = ModelWaveform2 (Target, Mask) % Returns predicted waveform and length of the signal.

DepthMask = size(Mask,1);  % # of rows in mask matrix
DepthTarget = size(Target,1); # of columns in target matrix

if DepthTarget > DepthMask % Error Message
  disp('Error: Depth of Target is greater than depth of Mask')
  return  
elseif DepthTarget < DepthMask % Error Message
  disp('Error: Depth of Target is less than depth of Mask')
  return
end

Length = size(Target,2) + size(Mask,2)-1; #Length due to length of the convolution of two vectors.
IntensityVec = zeros(1,Length);  %Instantiate Intensity vector

for i = 1:DepthMask % Iterate through all rows of the target and mask matrices. 
  Y = conv(Mask(i,:),Target(i,:));  % Convolve rows of target and mask 
  IntensityVec = IntensityVec + Y;       
end

Intensity = IntensityVec;    
endfunction
