(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    115532,       2599]
NotebookOptionsPosition[    110035,       2461]
NotebookOutlinePosition[    110379,       2476]
CellTagsIndexPosition[    110336,       2473]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Equivalency of the Area Function with the Standard Approach", "Title",
 CellChangeTimes->{{3.7176395981069937`*^9, 
  3.7176396142298975`*^9}},ExpressionUUID->"05ad9a2c-75ea-45c9-8111-\
af5aadf98ff8"],

Cell[CellGroupData[{

Cell["The Standard Approach - The Circular Target", "Section",
 CellChangeTimes->{{3.7176399820968113`*^9, 3.7176402512791157`*^9}, {
  3.717640314132371*^9, 3.7176403155341005`*^9}, {3.717641697873081*^9, 
  3.71764170358829*^9}},ExpressionUUID->"e8925850-6b80-494d-90fd-\
19e2e19b7bfc"],

Cell[TextData[{
 StyleBox["The standard, unsimplified method relies on using a double \
integral in x and y and yields a signal in the time domain. In standard \
SPIFI, since there is no y component, it is easy to make the integral for the \
time domain signal look like a Fourier Transform, but alas, we have not that \
luxury. We start by defining a fluorescent circular target of radius ", "Text",
  FontColor->GrayLevel[0]],
 StyleBox[Cell[BoxData[
  FormBox[
   FractionBox["1", "2"], TraditionalForm]], "Text",
  FormatType->"TraditionalForm",
  FontColor->GrayLevel[0],ExpressionUUID->
  "3f73f5b6-2cc2-43cc-b7a7-51ea9944ec13"], "Text"],
 StyleBox[", centered at x = ", "Text",
  FontColor->GrayLevel[0]],
 StyleBox[Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "and", " ", "y"}], " ", "=", " ", 
     FractionBox["1", "2"]}], "Text"], TraditionalForm]], "Text",
  FormatType->"TraditionalForm",
  FontColor->GrayLevel[0],ExpressionUUID->
  "e05db04e-ca5d-4d3e-89b8-d99ba9556ac3"], "Text"],
 StyleBox[". This way, the target lies completely in quadrant I of the real \
plane.  This makes the math a lot more convenient.", "Text",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{
  3.7176403238783045`*^9, {3.717640423948595*^9, 
   3.7176404257584105`*^9}},ExpressionUUID->"663b13ea-04a1-4d18-82da-\
cc943b3155b8"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", " ", "=", " ", 
   RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", " ", "=", " ", 
   RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", " ", "=", " ", 
   RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{
        RowBox[{"r", "^", "2"}], "\[GreaterEqual]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "-", "a"}], ")"}], "^", "2"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"y", "-", "b"}], ")"}], "^", "2"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"r", "^", "2"}], "\[LessEqual]", "  ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "-", "a"}], ")"}], "^", "2"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"y", "-", "b"}], ")"}], "^", "2"}]}]}]}], "}"}]}], "}"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.7176395254501457`*^9, 
  3.717639525856227*^9}},ExpressionUUID->"8da788c1-576c-44fc-a452-\
7aaf89dd3e5b"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"1", 
        RowBox[{
         FractionBox["1", "4"], "\[GreaterEqual]", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "2"]}], "+", "x"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "2"]}], "+", "y"}], ")"}], "2"]}]}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{
  3.7176395614569654`*^9},ExpressionUUID->"8b4feed3-78ec-4267-9b7c-\
72f5c0861c7b"]
}, Open  ]],

Cell["\<\
Next, we compute the function for the time domain signal using the double \
integral. Note, we force the y integration to take place first, as \
Mathematica does not return a \[OpenCurlyDoubleQuote]nice\
\[CloseCurlyDoubleQuote] answer otherwise. These sorts of integrals can be \
rather challenging to perform analytically.\
\>", "Text",
 CellChangeTimes->{{3.717640259801795*^9, 3.717640260485113*^9}, {
  3.7176403276172543`*^9, 
  3.7176403922442284`*^9}},ExpressionUUID->"d9b6f731-cc98-47c3-9a88-\
8cfe004c7b78"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"F", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ")"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "\[Pi]", " ", "y", " ", "t"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7176395409744587`*^9, 
  3.7176395585863266`*^9}},ExpressionUUID->"fd16564c-89fb-41d0-a3b6-\
a0d5f92cf90f"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"BesselJ", "[", 
    RowBox[{"1", ",", 
     RowBox[{"\[Pi]", " ", "t"}]}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Pi]", " ", "t"}], "]"}]}], 
  RowBox[{"2", " ", "t"}]]], "Output",
 CellChangeTimes->{
  3.7176395634046483`*^9},ExpressionUUID->"0af5b981-487b-49fd-b894-\
4a73c7f39b24"]
}, Open  ]],

Cell["\<\
We find that, without a window function, our time domain signal produced by a \
fluorescent circular target will be an oscillating function. Note that while \
the signal shown here is negative at times (which is unphysical), the result \
is still valid. We are actually computing the signal corresponding to the \
first sideband: there is a DC component that, while present, is not terribly \
relevant to our discussion.\
\>", "Text",
 CellChangeTimes->{{3.7176404119772387`*^9, 3.717640491285284*^9}, {
  3.717640726785971*^9, 3.7176407441607075`*^9}, {3.717640828089044*^9, 
  3.717640917817317*^9}},ExpressionUUID->"63dde5ec-22dc-47bb-9cf6-\
80849dd34dfa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"BesselJ", "[", 
      RowBox[{"1", ",", 
       RowBox[{"\[Pi]", " ", "t"}]}], "]"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Pi]", " ", "t"}], "]"}]}], 
    RowBox[{"2", " ", "t"}]], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
   RowBox[{"Frame", "->", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"t", ",", "Amplitude"}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{
    "Time", " ", "Domain", " ", "Signal", " ", "of", " ", "Fluorescent", " ", 
     "Target"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"{", "12", "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7176404960599895`*^9, 
  3.717640714695796*^9}},ExpressionUUID->"b4c191f4-f7f5-4154-b7e3-\
11d937b8d5b9"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVV3c81t8XNx/74fEgIyFSiNLQoK6S1eJbSkk2WVllZK+kQvbKlplNKo1z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        "]], LineBox[CompressedData["
1:eJwVV3c8198Xtvf6+EhlNCiVjGQVcW4iKpWGZGVL9shK2XvvFbJVKKNk5QqR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        "]]},
      Annotation[#, 
       "Charting`Private`Tag$99198#1"]& ], {}}, {{}, {}, {}}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["Amplitude", TraditionalForm], None}, {
     FormBox[
      TagBox["t", HoldForm], TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{-0.2, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.2, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.4, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.6, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.8, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-0.4, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-0.35, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-0.3, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-0.25, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-0.15, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-0.1, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-0.05, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.05, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.1, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.15, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.25, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.3, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.35, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.45, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.55, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.65, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.7, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.75, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.85, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.95, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{-4., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-5.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-5., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-4.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-3.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-3., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-2.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-1.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {-0.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {0.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {1.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {2.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {3.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {4.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {5., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {5.5, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}, {6., 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
        0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{469., Automatic},
  LabelStyle->{12},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
    RowBox[{
     "Domain", " ", "Fluorescent", " ", "of", " ", "Signal", " ", "Target", 
      " ", "Time"}], TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7176405094235506`*^9, 3.7176405211462464`*^9}, {
  3.717640556120819*^9, 3.7176406199982996`*^9}, {3.71764065666487*^9, 
  3.7176407152963943`*^9}},ExpressionUUID->"f796ed89-93e4-4b28-b354-\
264339a395bb"]
}, Open  ]],

Cell["\<\
Taking the Fourier Transform of the signal, we recover what we have \
previously defined as the \[OpenCurlyDoubleQuote]area function\
\[CloseCurlyDoubleQuote]. We will want to compare it to our mathematical \
definition of the area function using our work around.\
\>", "Text",
 CellChangeTimes->{{3.7176409403648205`*^9, 
  3.7176410145211563`*^9}},ExpressionUUID->"c2c847e7-ef3d-4930-b9f3-\
018f55d91ee1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", "\[Omega]_", "]"}], " ", "=", " ", 
  RowBox[{"FourierTransform", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"BesselJ", "[", 
       RowBox[{"1", ",", 
        RowBox[{"\[Pi]", " ", "t"}]}], "]"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Pi]", " ", "t"}], "]"}]}], 
     RowBox[{"2", " ", "t"}]], ",", "t", ",", "\[Omega]", ",", 
    RowBox[{"FourierParameters", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.717639675026682*^9, 
  3.717639683715804*^9}},ExpressionUUID->"e21ee6ba-867f-4e40-add8-\
ebcd2003b4c6"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]", " ", "\[Omega]"}], "-", 
       SuperscriptBox["\[Omega]", "2"]}]], "\[Pi]"], "+", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{"2", " ", "\[Pi]", " ", "\[Omega]"}], "-", 
       SuperscriptBox["\[Omega]", "2"]}]], "\[Pi]"], "-", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{
        RowBox[{"2", " ", "\[Pi]", " ", "\[Omega]"}], "-", 
        SuperscriptBox["\[Omega]", "2"]}]], " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"1", "-", 
        FractionBox[
         SuperscriptBox["\[Pi]", "2"], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"\[Pi]", "-", "\[Omega]"}], ")"}], "2"]]}], "]"}]}], 
     "\[Pi]"], "-", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "\[Pi]", " ", "\[Omega]"}], "-", 
        SuperscriptBox["\[Omega]", "2"]}]], " ", 
      RowBox[{"UnitStep", "[", 
       FractionBox[
        RowBox[{"\[Omega]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Pi]"}], "+", "\[Omega]"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Pi]", "+", "\[Omega]"}], ")"}], "2"]], "]"}]}], 
     "\[Pi]"]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.7176396848949423`*^9},ExpressionUUID->"9f3f1027-23ec-4831-a63e-\
5b738c5f171b"]
}, Open  ]],

Cell["\<\
The Fourier Transform is entirely real, so we can plot it directly.\
\>", "Text",
 CellChangeTimes->{{3.717641184316487*^9, 
  3.7176412035521736`*^9}},ExpressionUUID->"d0dd15fa-2af7-4ee5-907c-\
1f929e4f1279"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"H", "[", 
    RowBox[{"2", "\[Pi]", " ", "f"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.717639691517565*^9, 3.717639720898749*^9}, {
  3.717641036582863*^9, 
  3.71764103837062*^9}},ExpressionUUID->"6ef2ef35-3413-4225-bd03-\
317c46c6d911"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV03s41HkXAHBJyVZIJJsSW1Jb5NKF6IhWG6FVElq51UZvulCJCG9JZSNi
3bvILbYL6TLFQUITimaMMZffb8aYYTTzi4go3nn/+D7n+TznOed5znnO1zDw
uMchZSUlpRrF+380hUXS6WkKw6sed6pEr4Hj335J+jZBoTfHQq/SJxseVZkb
fxmlkNay1sHw0x0YOgaNnz5TOLT36+KkoSKwMHENFA9SeEWtdf31vWUQLvRR
IsUU5qzf5vjUvQKe5B0pYAsoVLWVcFRmPIRNCy72tLIo9NGuvJHX+xgi392I
bOqk8GWWNHpgrBJol24tqmujcG55/AylH1VgO0HzqHpNodfzqx9kgmqw7x2i
Zz+k8H0Ua/Ca7QuIz58+kn6fwq9E7cPdM2jQ4DVf9e8iCmfdSPK0qKPB9lYT
x7hcCttPfly7yvQV7Kw++PLwZQpjRjipQkYtXD1+zNs/gcLJnDsbjU4jtK6O
HvOOoVC4V35aVa0O3AoyLV3DKczfe+mA55068LjcVm55kMI8f+PorPp6SN/G
2bnOh8I3+HHDndkNwJjslxh7UnikeL5XinMD7DuhsuJnFwoNm6tPubxvAF/v
LXlKmyhsaH87HNz2GoJ/LUtuU6fQQ3oPtxW+gaK+p2ua1ShkTxQsFfW8AfGt
xpY6FQrHrX4bkixoghBtUuXJhBzPvHinZxzbBGE/FsXkiOV4W+dmMeXeDGff
Xzz2V60cc2t4hQ2cFkgePMMaeS7HD39E6G/UeAt3VUO2JVTJUSWxbXKdw1to
BVed/FI5+rzoCX1a/BaMHunUdKbJUbA40zUilA7tqcXztv4lx+SYDfml/Hdg
7NFSrq0pR5nVhrboxHawDaPp3P1JjrZxL0LiH7TDH1crLpjNkmPmNb+Hjl3t
cL4hdY/zhAzt7KRblFe+h04L78kLIhlaCWIXJuB7iFkodR58LsMswbKSkogP
wGDMldYHyFAypTyRd7UD4oOra8sPyDDZM7dmcU4HmI74pWd4yZAR4a0VX9YB
SQsrbUNcZbhaT9d6cUsH2HnsT9G0liH/WnbbIZVOKH5/z+qgpgxt/9HpKzrX
CZF0uwvfaz+hp8fVK51eH2Fp3XHtTfqf0DEh1p45wIBWrQ0RNrqfkBKMPzow
yoCoQxMf7bQ+oYWVXJOtxISuny6lb5/zCV1jL0ke6TIh1TNHy2NkECOj+Fz+
dibMHGzUPNY6iAvXfC92yGfCgM7P8wvPD+IJhrEkw6kLqo82ztLgSfHnKyuF
zrEs2Lw8zLyYJcXyXL3KHUksoDF0/7TrlGLay5PuW9JYUGd39MnRZilSedXL
VYtZQNfQCmp5LEV7A76vRRsLyKqDdfGJUszr635L6nXDT98nokbMpHjkLr1N
VNEN/snmn9kJA9jsZgNRL9kQ9SQtsS1mAC2r2iZlDWzI4H7Rr48cwOA8s3xf
Ohvoa5/uLA1TODSkcAWbDZZtNoVnfAYw/VCdW9hXNsxW375vocUA7iltTxKZ
9UBFyr5XuwT9+Hz0LBFT0APjadFJCP2olR2QvOcoByT69VInm350NOzRFJ/k
QFfxbNd2q37cJxwrPhXJgSrajQW81f24bY6GXtQlDoQJS3ImFvZj2+3/XHG4
xYFec0bFhn4JdiivMqnp4ED7h7Ud5akSnG2ZsjvCgguvfE5ZWl6T4HGDHY93
b+ZCuehZBu2SBPXrvfJXbeVC0riDz9soCW6lzVz5ZicXHJd794qDJUj3rXdH
fy48P35p1NBags3qxEDl31woVOfrZQnEuEJNQq/o5UKaL6hac8V4MKE6sqWf
Cwmlt0fYXWLM5Ps6EDIuBDoEvV/SKkbpkRjLqTEuGJ3pv3jrqRjPGDswZszj
wV3eMFV8TYz0qLItRpY8uF2h2lS9QYzLE33Wd8fwIPXbkap968V4zrhf7UAC
D+Kc6LfH1ohx5vhyZ04iD/zJ5Gjr5WIctR+b3ZrCAwNtLfOan8RoNLWu4swd
HhRE6+c1En3IiMoNGX7Ngzxn81Mfr/ShFafa7MYsPqyY60z/cLEPJ82zm7ep
8aH8XaBR+4U+FHdq3pTP4wNt183OltN96IAuH2y1+cB2G7OoDVD02xX4vdyI
D4v21Hwpte5D5/N8966tfEjx3Xk6dkCELCO6IChCkdcPbIsWiVDNQPef/LN8
KOBGrTxHiBA6bpV9jOLDgz8rmOFMESp3Tkit4vnQelBjY0i9CK+cuTH17m8+
zAlmft2TLUJzXd8A12I+JPwnIHL1ThGGeYbG3GPwgX/dL4/mKELxxrXtJSw+
2Dz2rXPZKsKLKSPTxT18GB71nBNmKUK36qC52SQfAi44Z1UuFaFL5kehyyc+
2KdZPt8y3ItFNbIMmTIBU89mjbvm9qLWY4Mqk3UE+PQo6xMZvbjzQ+Lu+2YE
PP0+DSdSe/HnidNDqywICNs2cTntUi/+rvxqm+4mAnh0uS7reC/OUTHd2GRP
wCsea5P/9l585P/D5vAeAqJn3j97SibE8Jou2pPTivpsv9n+/UJM8ar1zjxL
QKDZwgzXXiEu2diXGXGOAGff85UmbCGmzdgvN44hYHGVm4zfKESXgYNGQRcJ
eBL4JdAlT4iby48Z2KQRUDpeMrT5HyEaTPMkfekE5F4/EGecJsQYpQKv6xkE
JNDe5M9IEqLjkVVmzCwC/tDK6n4WLkQ+2dVqc4sAeb2t2woXIR7Wv2lxuJwA
odcQd4GTEEn+gwpuBQFMWdHRaXshWud+Z7o/UMynp3GlZ6MQm6gZm9c+JuDa
ScHrVCMh9nf/6lTzlAATw0TrH98EOG/JokH7egL0n9m0SEcE+Ory9eSEBgI0
XKl93ZQAd09+7617TcDXyP0RVX0CFAQ7PbVsIqDxw5qHIR0CvM/X/TJEJyAg
7v2KrlIBnizLXNbxkYB97FtbeYUC7MiXqLIZin1ZnNgvKhDgXsbxNh6TACuR
ZvLwTQHGFHvLeSwC5vzu8UU9XoC/mDelPOcQ8OO20fxF5wW42WNuUAmXgOFv
w8ZLzwrQZJCpnc4jgFOe7vPrMQFWhmrqBBAEPNBg1u/wFqDTnbMpLCEBhUeK
OG57BZhoucvv314CsupPj3q6C/Ct17P5cSIC4sMXrQ7+TYBfpTs09MUE7GV5
pcaZC9C0jFNoOkDAZEGP3ws1AVoNz95eKyfg89j9yDoVAVpnWG8KpAgQ7Y5O
a54m0bnkhPrMzwS0K+s3MUdJrNcsCdkyRMDdw3+uGxaQ+HL9su7ELwT8g+t2
fOOSGDcZ9HnBCAHJi6f8lbpJ1LadJ89W+DS94KZ6O4m/VBvm3B4l4HdTcnIN
jcSU2PMvksYIsLv8SMeimsS8/eNKkwpbkHFm1o9IjNefMA0dJ2BJmmHQjmJS
8R80AL4RoDk4dN7tDonXKwMMixRW2d6Q6ZlHYmNQtVR1QnFPo4H0oDQSaQYM
i0aFe90sRaF/k1jEYz5eOklAd8nMqZNJJJp2OC2OULjB+555XCyJnu3sXN3v
BDyrjHC5fI5E8e5fXwQrXDH3t0PXI0jcOulc+0DhjJq+rLxQEo3ad8ZZ/yDA
LzIndtMhEhnG2dkXFDaxdA/uPEjibnio3qDwkGym8zEfEpe9vUsoTRFAK31u
NseTxJaNV+bZKvzfoGM6he4kznp1JiNc4V3LjCbtnElkusZGlSjMT7/WFA4k
JloYeqtME1DiZl+hbkPinE1cj3UKn1AbvVFmRWJm+edSD4WtG8vObjcj8aTr
Ud8IhZUv+P1JrCaxKdcrNE3hd9YLHaNWkPiOhcwKhW+ONJvoGJD4RuXf/NcK
+z08r/5Ij8Sl/cYNXQqvCjUfcdYmMVzNylGs8OcVYnafOom5lezlwwq/IHIw
To3EJ9QS3wmF69+tjrSeRWJymJPLlML/A62nnrU=
        "]], LineBox[CompressedData["
1:eJwV03k01N0fB/AoUvyQFkqPJFFSdqXFJ3spoihLlJKkUmRJCaUkichSkkb2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        "]], LineBox[CompressedData["
1:eJwV03k0lfkDx3FDRZSMSY2iUNmypEki9amxjLSJRkqEInFliRRlVylJtoqy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        "]], LineBox[CompressedData["
1:eJwV1Xk01fkbB3BLhES2JrJMWYokld3wVqZoodwoIyJTmhayRqZFaLG2GZEM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        "]]},
      Annotation[#, 
       "Charting`Private`Tag$101507#1"]& ], {}}, {{}, {}, {}}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-1, 1}, {0., 0.4999995932682644}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.717639713431378*^9, 3.717639721107304*^9}, 
   3.7176410386433463`*^9},ExpressionUUID->"a6db7c7d-b51b-4765-8e53-\
7b48f343a00c"]
}, Open  ]],

Cell["\<\
Interesting. We see zeros at f = 0 and f = 1, which makes sense based upon \
the size of the target. The widest point in the x direction of the target is \
at y = 0.5, which corresponds to a maximum in the plot above. Note that the \
above is the Fourier Transform. In a labratory setting, we would be most \
often computing the one sided periodogram. The periodogram of the above \
Fourier Transform would just be the positive frequency peak multiplied by two.\
\>", "Text",
 CellChangeTimes->{{3.717641026877035*^9, 3.7176411724945283`*^9}, {
  3.7176412504294176`*^9, 
  3.7176412938865585`*^9}},ExpressionUUID->"2a856f58-3683-4e33-a041-\
2bbfbfa0fb5c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Area Function Definition - The Circular Target", "Section",
 CellChangeTimes->{{3.717641299602268*^9, 3.717641307693299*^9}, {
  3.7176417059300213`*^9, 
  3.717641710559841*^9}},ExpressionUUID->"035a3f55-856c-4eca-9795-\
da6d047776c7"],

Cell["\<\
Now, we must test the veracity of our claim that the area function can be \
computed using a single integral. We first compute the area function (based \
on our mathematical definition) for our target.\
\>", "Text",
 CellChangeTimes->{{3.7176413150052557`*^9, 
  3.717641349736679*^9}},ExpressionUUID->"0e47897c-0882-46ab-870f-\
134664503410"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"G", "[", "y_", "]"}], " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",ExpressionU\
UID->"9092897b-9c22-4b88-992f-165aace324fd"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"1", 
        RowBox[{"y", "\[Equal]", 
         FractionBox["1", "2"]}]},
       {
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}]}], " ", "y"}]]}], 
        RowBox[{
         RowBox[{"0", "<", "y", "<", 
          FractionBox["1", "2"]}], "||", 
         RowBox[{
          FractionBox["1", "2"], "<", "y", "<", "1"}]}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{
  3.717639782144225*^9},ExpressionUUID->"e7930545-3f45-4fa2-9ae7-\
59867120fa02"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"G", "[", "y", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.717641368678584*^9, 3.7176413710960174`*^9}, {
  3.717641517281522*^9, 
  3.7176415177633038`*^9}},ExpressionUUID->"729e23cf-bc6e-4959-809e-\
d73ef22d31d3"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAmIQrWcv9ur///f7GaAg/6dyx89fCP6GzYZqn78i+EYa
vknPXiP45oItt85cR/AdHn88NXM9gh/Ufna1cTyCX36+JTd93zs4/8oV7lcH
E9/C+bIH8kXMZd7A+Vuzj7Dy330F5yf0GH642fQSzv8xqbpjv/0LOH8x3z3J
GQ+fwflzvAyLLnc+hfObchIrND2fwPnVzKvKi94+gvMTG86rXFvxEM6fuvfp
jDlZD+D8Xfc1eNYo3YPzlQUcnELm3YbzN2l1ZD16fAPOv390o4KZ2TU4/6nO
VKP92y7D+YJ1K830GC/C+Tpm73WWfj4D5ze7vL2ws+I4nC8asm5CpPghhH3f
jvKfUNkF5y+9/bT3Zcs6OP9Wjdj8ucYIPp+c+4bAR2vh/LKEFZd22iP4bk+z
xLt+rYbzX7x7v0CrYCWcr8X0a3N29BI4P26x1lF5LgR/kkv0tcs7FsP5v9r2
/LAWQ/BPc9fb8lxcCOff0OLoi+ydB+fHBspsuZ08Bc5/8/mrZemRyXB+zbTz
+/lUEfw5t5tOOz6bCOdvOX3pqP/FPjh//Zcc5Re3WuD8c5YK+tJzmuH8d3WX
rfxim+D8CKGSJRn76+H8YGs+JsaTpQj/HS2RTPcuhvMv+N82OHu2AM6ffSJg
v9HSdDhf4q7su38rk+B87cdXLafFRsP5ajwF0/XSA+F8S1b95Q+eusD5AOwG
CI4=
        "]], LineBox[CompressedData["
1:eJwV03k01A0XB3APiiR5PGmlUNmypOeRSH3rsbzSpvRKiSQkRpZGRNlVWiRJ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        "]], LineBox[CompressedData["
1:eJwVlnk8VVsbx42FTJHezLcMNxIqMl1+lQalxCnVFZFbuk0yU7dBRaLS5BXJ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        "]]},
      Annotation[#, 
       "Charting`Private`Tag$104289#1"]& ], {}}, {{}, {}, {}}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-1, 1}, {0., 0.9999991865365289}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.717639791849551*^9, 3.717641371278002*^9, 
  3.717641524781479*^9},ExpressionUUID->"4791be64-6976-48ee-a1f3-\
4de71305f124"]
}, Open  ]],

Cell["\<\
This looks rather familiar. In fact, it looks exactly like what we would \
expect the one sided periodogram of the Fourier Transform of the standard \
approach time domain signal.  It has the right shape, the zeros in the right \
places and a maximum that makes sense.  Lets compute its Fourier Transform, \
since we claim that the time domain signal (sans the window function) is \
equal to the Fourier Transform of the area function.  We must not forget to \
take the real part of the Fourier Transform, as we required in our \
derivation. \
\>", "Text",
 CellChangeTimes->{{3.71764135996239*^9, 3.717641530881211*^9}, {
  3.7176415641081285`*^9, 
  3.717641579845005*^9}},ExpressionUUID->"bbc2f5c7-2e11-49af-b9b5-\
ee9ef0c4030f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"FourierTransform", "[", 
     RowBox[{
      RowBox[{"G", "[", "y", "]"}], ",", "y", ",", 
      RowBox[{"2", "\[Pi]", " ", "t"}], ",", 
      RowBox[{"FourierParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}], "]"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{
     RowBox[{"t", " ", "\[Element]", " ", "Reals"}], " ", "&&", 
     RowBox[{"t", ">", "0"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7176398167107077`*^9, 3.717639962711727*^9}, 
   3.717641875300725*^9},ExpressionUUID->"f6307bf8-e610-4a9b-a7c7-\
dfc3f2fde58f"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"BesselJ", "[", 
    RowBox[{"1", ",", 
     RowBox[{"\[Pi]", " ", "t"}]}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Pi]", " ", "t"}], "]"}]}], 
  RowBox[{"2", " ", "t"}]]], "Output",
 CellChangeTimes->{{3.717639821687451*^9, 3.7176398680738883`*^9}, {
   3.7176399141555133`*^9, 3.7176399324933105`*^9}, 3.7176399634687414`*^9, 
   3.7176418783969636`*^9},ExpressionUUID->"85d7ce6a-2899-45d6-835b-\
c818a013030e"]
}, Open  ]],

Cell["\<\
This gives us the exact same time domain signal that we had before. \
Outstanding.\
\>", "Text",
 CellChangeTimes->{{3.7176416404151845`*^9, 
  3.7176416711108665`*^9}},ExpressionUUID->"b75f75e5-1e59-4b09-9b85-\
4c966dad4378"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.717639838444542*^9, 
  3.7176398398843737`*^9}},ExpressionUUID->"0ff9f98d-7e28-4127-adcb-\
4553b99962d9"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Second Case - The Square Target", "Section",
 CellChangeTimes->{{3.7176417187551494`*^9, 
  3.717641734457935*^9}},ExpressionUUID->"16c4970e-f6f2-456d-8f95-\
3eb3fd90c06a"],

Cell[TextData[{
 "We consider another simple case to test the validity of our definition of \
the area function: that of a square target. We define our target to be a \
square of height and width equal to unity, centered at x = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "and", " ", "y"}], " ", "=", " ", 
     FractionBox["1", "2"]}], ","}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "7231c103-baeb-48de-8629-21c770b0202f"],
 " just as we did for the circular target.  "
}], "Text",
 CellChangeTimes->{{3.717641983505668*^9, 
  3.7176420578916116`*^9}},ExpressionUUID->"58d3e38b-14e8-42ff-a417-\
5eb91fca4989"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"F1", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{
        RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "1"}], " ", "&&", 
        " ", 
        RowBox[{
        "0", "\[LessEqual]", " ", "y", " ", "\[LessEqual]", " ", "1"}]}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{
        RowBox[{"x", ">", "1"}], " ", "||", " ", 
        RowBox[{"y", " ", ">", "1"}]}]}], "}"}]}], "}"}], "]"}]}]], "Input",Ex\
pressionUUID->"c2be2878-fbbc-416e-a466-861049c47fda"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"1", 
        RowBox[{
         RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "1"}], "&&", 
         RowBox[{"0", "\[LessEqual]", "y", "\[LessEqual]", "1"}]}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{
  3.717641781295574*^9},ExpressionUUID->"9b04ae55-991d-4c7a-accc-\
eafa0aa654c1"]
}, Open  ]],

Cell["\<\
Using the \[OpenCurlyDoubleQuote]brute force\[CloseCurlyDoubleQuote] tactic \
that does not use a Fourier Transform, we compute the signal produced by a \
fluorescent square target.\
\>", "Text",
 CellChangeTimes->{{3.717642065547484*^9, 
  3.7176420957719126`*^9}},ExpressionUUID->"46791f66-0298-4772-a61b-\
ae2016e73b47"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"F1", "[", 
     RowBox[{"x", ",", "y"}], "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"2", "\[Pi]", " ", "y", " ", "t"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",ExpressionUUID\
->"41d08a8c-096d-46a0-84b6-08eab8169ee2"],

Cell[BoxData[
 FractionBox[
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "\[Pi]", " ", "t"}], "]"}], 
  RowBox[{"2", " ", "\[Pi]", " ", "t"}]]], "Output",
 CellChangeTimes->{
  3.717641783980218*^9},ExpressionUUID->"a689aebf-d23a-4ee3-b44a-\
b342353c383e"]
}, Open  ]],

Cell["\<\
A Sinc function: fascinating. But does our predicted area function give us \
the same result?  We compute the area function using our definition.\
\>", "Text",
 CellChangeTimes->{{3.717642106678435*^9, 
  3.7176421439355774`*^9}},ExpressionUUID->"6cc88361-92f9-488d-b1fe-\
242b300b7ea4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"G1", "[", "y_", "]"}], " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"F1", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",ExpressionU\
UID->"5a86af6a-e7d5-414f-afd2-65b325164d4c"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"1", 
        RowBox[{"0", "\[LessEqual]", "y", "\[LessEqual]", "1"}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{
  3.7176417859083486`*^9},ExpressionUUID->"296a18dd-2dd5-49d3-87ff-\
232e9a62f10e"]
}, Open  ]],

Cell["\<\
We take the real part of the Fourier Transform of the area function as we did \
before.\
\>", "Text",
 CellChangeTimes->{{3.7176421958066072`*^9, 
  3.717642211619687*^9}},ExpressionUUID->"8c4552cb-f7fd-4a5c-93e2-\
9e130b8e0586"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"FourierTransform", "[", 
     RowBox[{
      RowBox[{"G1", "[", "y", "]"}], ",", "y", ",", 
      RowBox[{"2", "\[Pi]", " ", "t"}], ",", 
      RowBox[{"FourierParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "1"}], "}"}]}]}], "]"}], "]"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{
     RowBox[{"t", " ", "\[Epsilon]", " ", "Reals"}], " ", "&&", " ", 
     RowBox[{"t", ">", "0"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.717641796064875*^9, 3.717641802581216*^9}, {
   3.717641836297937*^9, 3.7176418998350134`*^9}, 3.717641967334133*^9, {
   3.717642228797397*^9, 
   3.717642229554412*^9}},ExpressionUUID->"abd10903-6a61-4e82-be90-\
820e00d3987b"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Pi]", " ", "t"}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Pi]", " ", "t"}], "]"}]}], 
  RowBox[{"\[Pi]", " ", "t"}]]], "Output",
 CellChangeTimes->{{3.7176417882555947`*^9, 3.7176418029742613`*^9}, 
   3.717641924419433*^9, {3.717642226125788*^9, 
   3.7176422302292075`*^9}},ExpressionUUID->"618340d0-6bfc-4003-a9c2-\
b2453c96f699"]
}, Open  ]],

Cell[TextData[{
 "By recalling that Cos[\[Pi] t] Sin[\[Pi] t] = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "\[Pi]", " ", "t"}], "]"}], "2"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "945e6f1b-feb8-4ae1-8c1a-f944856ea30f"],
 ", we see that the Fourier Transform of the area function is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Pi]", " ", "t"}], "]"}], 
     RowBox[{"2", " ", "\[Pi]", " ", "t"}]], ","}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "217f8a27-5059-4e1e-9657-509d0760f6d8"],
 " as was required using the brute force method."
}], "Text",
 CellChangeTimes->{{3.7176422348640413`*^9, 
  3.7176423204021606`*^9}},ExpressionUUID->"c1ae96f1-0f65-4387-bac6-\
82ed968d8729"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusion", "Section",
 CellChangeTimes->{{3.717642333371172*^9, 
  3.7176423391039267`*^9}},ExpressionUUID->"3ca23d40-c098-4873-a82d-\
db251325a87d"],

Cell["\<\
In two simple test cases (that are actually quite physically realizable), we \
see that our definition of the area function matches what is required by the \
brute force approach. This means that we can use our definition of the area \
function to ascribe meaning to time domain signals produced by our spinning \
mask system architecture.\
\>", "Text",
 CellChangeTimes->{{3.717642342163067*^9, 
  3.71764246631444*^9}},ExpressionUUID->"1c5282ce-18ea-4837-88fc-\
2700e93f27ca"],

Cell["", "Text",
 CellChangeTimes->{{3.717641813427077*^9, 
  3.717641832690838*^9}},ExpressionUUID->"36ae58cd-2714-4be9-8603-\
8ce473aa1ec3"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 997},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 206, 3, 101, "Title", "ExpressionUUID" -> \
"56b9f8e0-61e7-4bc6-ba43-124fe2c99557"],
Cell[CellGroupData[{
Cell[811, 29, 288, 4, 70, "Section", "ExpressionUUID" -> \
"aeb4d242-d315-4149-9bee-690f54fef16e"],
Cell[1102, 35, 1384, 32, 61, "Text", "ExpressionUUID" -> \
"97a55f29-0c93-4fb4-81e8-1777f2b44e1e"],
Cell[CellGroupData[{
Cell[2511, 71, 1344, 41, 88, "Input", "ExpressionUUID" -> \
"c4a24012-cb4f-4062-9656-08d958c3cbb9"],
Cell[3858, 114, 1986, 59, 59, "Output", "ExpressionUUID" -> \
"6e8bc773-0e08-459e-aea2-2a5fd2fd7f03"]
}, Open  ]],
Cell[5859, 176, 527, 10, 30, "Text", "ExpressionUUID" -> \
"eb5b50fa-3102-432d-be31-0ae3fdc248ec"],
Cell[CellGroupData[{
Cell[6411, 190, 527, 15, 30, "Input", "ExpressionUUID" -> \
"d4f5ec82-26aa-42dc-aaf2-0b0f4ba47322"],
Cell[6941, 207, 348, 11, 55, "Output", "ExpressionUUID" -> \
"32fd2b8a-dd7c-466b-9114-1e49147f27ca"]
}, Open  ]],
Cell[7304, 221, 669, 11, 49, "Text", "ExpressionUUID" -> \
"d36a45fb-9a4d-43c4-85cb-b289fb7301fe"],
Cell[CellGroupData[{
Cell[7998, 236, 953, 27, 55, "Input", "ExpressionUUID" -> \
"071d9b63-17cc-4d27-b488-385d4418188a"],
Cell[8954, 265, 54405, 1106, 331, "Output", "ExpressionUUID" -> \
"51e8b20c-c473-40b2-8611-a4017af8b095"]
}, Open  ]],
Cell[63374, 1374, 417, 8, 30, "Text", "ExpressionUUID" -> \
"46bedbc4-252b-4b9a-a582-fbb1b916fcf1"],
Cell[CellGroupData[{
Cell[63816, 1386, 655, 18, 55, "Input", "ExpressionUUID" -> \
"c9fc6810-16dd-445b-95fe-b654985959ea"],
Cell[64474, 1406, 1520, 49, 93, "Output", "ExpressionUUID" -> \
"3ab53701-7aca-4105-918a-331c2384d407"]
}, Open  ]],
Cell[66009, 1458, 219, 5, 30, "Text", "ExpressionUUID" -> \
"f4b2ad6a-b4bf-4bde-82bd-20e212db1259"],
Cell[CellGroupData[{
Cell[66253, 1467, 397, 11, 30, "Input", "ExpressionUUID" -> \
"76dded8d-713d-4d50-a763-b01132982484"],
Cell[66653, 1480, 17117, 301, 241, "Output", "ExpressionUUID" -> \
"a31631d0-2e80-4207-81e6-83bee235957f"]
}, Open  ]],
Cell[83785, 1784, 666, 11, 49, "Text", "ExpressionUUID" -> \
"19591b2f-1d52-4779-9ef5-82e202fa29be"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84488, 1800, 246, 4, 70, "Section", "ExpressionUUID" -> \
"d315f9f6-49d4-4df1-adaf-f2b0f3a88727"],
Cell[84737, 1806, 353, 7, 30, "Text", "ExpressionUUID" -> \
"66be4fa5-924a-45c0-9b83-96a20a9dfb64"],
Cell[CellGroupData[{
Cell[85115, 1817, 322, 9, 30, "Input", "ExpressionUUID" -> \
"7d075658-672d-460e-86d9-061d908b4885"],
Cell[85440, 1828, 2019, 61, 80, "Output", "ExpressionUUID" -> \
"bc661b45-d7cd-4793-a775-e38198d8f55d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87496, 1894, 368, 10, 30, "Input", "ExpressionUUID" -> \
"89af8a0d-53d4-4658-bb6b-16bcdbd71c12"],
Cell[87867, 1906, 9915, 183, 241, "Output", "ExpressionUUID" -> \
"f5e209e4-b401-427d-97fb-3061b48a76ef"]
}, Open  ]],
Cell[97797, 2092, 742, 13, 49, "Text", "ExpressionUUID" -> \
"ee6f50fc-0e24-4184-892a-bf63eafdbc2d"],
Cell[CellGroupData[{
Cell[98564, 2109, 680, 17, 30, "Input", "ExpressionUUID" -> \
"ae21c41e-8a70-41bb-9450-fbc2822b754f"],
Cell[99247, 2128, 475, 12, 48, "Output", "ExpressionUUID" -> \
"77599ff1-17d5-4436-bb33-d495ef8b4c22"]
}, Open  ]],
Cell[99737, 2143, 236, 6, 30, "Text", "ExpressionUUID" -> \
"ef653af4-7a8a-4e9e-af9f-0dbb17a91e5b"],
Cell[99976, 2151, 154, 3, 30, "Input", "ExpressionUUID" -> \
"1707b96b-8670-4c7e-9367-66d1815076cd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100167, 2159, 180, 3, 70, "Section", "ExpressionUUID" -> \
"b003405d-5356-4399-9b77-d772068d4863"],
Cell[100350, 2164, 698, 17, 42, "Text", "ExpressionUUID" -> \
"21f53609-2627-4b75-ad7e-ec8f15479fcf"],
Cell[CellGroupData[{
Cell[101073, 2185, 670, 20, 30, "Input", "ExpressionUUID" -> \
"18a6c1b4-025f-4b65-98e7-e3f80f33c937"],
Cell[101746, 2207, 1719, 49, 46, "Output", "ExpressionUUID" -> \
"6b2fa684-0c25-4698-9bc5-6db5359583d4"]
}, Open  ]],
Cell[103480, 2259, 333, 7, 30, "Text", "ExpressionUUID" -> \
"d554ae81-f672-403a-abfe-cad153334f87"],
Cell[CellGroupData[{
Cell[103838, 2270, 423, 12, 30, "Input", "ExpressionUUID" -> \
"1baf7f5a-bc60-4c7b-b5b8-1c644639c676"],
Cell[104264, 2284, 255, 7, 48, "Output", "ExpressionUUID" -> \
"911b2059-1bae-4f9e-b963-281517fe5586"]
}, Open  ]],
Cell[104534, 2294, 297, 6, 30, "Text", "ExpressionUUID" -> \
"cc27d1a0-0ab9-4520-9585-a32d5797fdad"],
Cell[CellGroupData[{
Cell[104856, 2304, 324, 9, 30, "Input", "ExpressionUUID" -> \
"a99337a7-7e17-48f4-9fa5-a5aa5337ebf2"],
Cell[105183, 2315, 1628, 47, 46, "Output", "ExpressionUUID" -> \
"114d4173-9b9f-46a1-b2c0-5c2865ef1619"]
}, Open  ]],
Cell[106826, 2365, 239, 6, 30, "Text", "ExpressionUUID" -> \
"49858685-f746-4156-b592-0dbec44ae2a4"],
Cell[CellGroupData[{
Cell[107090, 2375, 791, 19, 30, "Input", "ExpressionUUID" -> \
"a1dd8517-1b43-413f-9fc0-ae583e1da4c6"],
Cell[107884, 2396, 423, 11, 48, "Output", "ExpressionUUID" -> \
"699f046b-05bd-4735-8439-3d5c6dab917b"]
}, Open  ]],
Cell[108322, 2410, 855, 23, 43, "Text", "ExpressionUUID" -> \
"b9ae8464-c80e-415c-bf42-814aec99dac5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[109214, 2438, 157, 3, 70, "Section", "ExpressionUUID" -> \
"76d544f3-977c-4388-9106-bc001c6d8ead"],
Cell[109374, 2443, 488, 9, 49, "Text", "ExpressionUUID" -> \
"b7396569-0010-42e2-94ef-5163230ae852"],
Cell[109865, 2454, 142, 3, 30, "Text", "ExpressionUUID" -> \
"86146a0c-ddcd-4b74-9ae0-5e41b4ea5232"]
}, Open  ]]
}, Open  ]]
}
]
*)

